@@ -11,6 +11,7 @@ import pendulum
 from .date import Date
 from .time import Time
 from .period import Period
+from .exceptions import PendulumDeprecationWarning
 from .exceptions import PendulumException
 from .tz import Timezone, UTC, FixedTimezone, local_timezone
 from .tz.timezone_info import TimezoneInfo
@@ -352,6 +353,12 @@ class Pendulum(Date, datetime.datetime):
 
         :rtype: Pendulum
         """
+        warnings.warn(
+            'The create() helper will no longer exist in version 2.0. '
+            'Use datetime() instead.',
+            PendulumDeprecationWarning,
+            stacklevel=2
+        )
         tz = cls._safe_create_datetime_zone(tz)
 
         if any([year is None, month is None, day is None]):
@@ -403,7 +410,7 @@ class Pendulum(Date, datetime.datetime):
                 'Using the classic formatter in from_format() '
                 'is deprecated and will no longer be possible '
                 'in version 2.0. Use the alternative formatter instead.',
-                DeprecationWarning,
+                PendulumDeprecationWarning,
                 stacklevel=2
             )
             dt = datetime.datetime.strptime(time, fmt)
@@ -512,28 +519,68 @@ class Pendulum(Date, datetime.datetime):
 
         :rtype: Pendulum
         """
+        warnings.warn(
+            'The copy() method will be removed in version 2.0. ',
+            PendulumDeprecationWarning,
+            stacklevel=2
+        )
         return self.instance(self._datetime)
 
     # Getters/Setters
 
     def hour_(self, hour):
-        return self._setter(hour=hour)
+        warnings.warn(
+            'The hour_() method will be removed in version 2.0. '
+            'Use set(hour={}) instead.'.format(hour),
+            PendulumDeprecationWarning,
+            stacklevel=2
+        )
+
+        return self.set(hour=hour)
 
     def minute_(self, minute):
-        return self._setter(minute=minute)
+        warnings.warn(
+            'The minute_() method will be removed in version 2.0. '
+            'Use set(minute={}) instead.'.format(minute),
+            PendulumDeprecationWarning,
+            stacklevel=2
+        )
+
+        return self.set(minute=minute)
 
     def second_(self, second):
-        return self._setter(second=second)
+        warnings.warn(
+            'The second_() method will be removed in version 2.0. '
+            'Use set(second={}) instead.'.format(second),
+            PendulumDeprecationWarning,
+            stacklevel=2
+        )
+
+        return self.set(second=second)
 
     def microsecond_(self, microsecond):
-        return self._setter(microsecond=microsecond)
+        warnings.warn(
+            'The microsecond_() method will be removed in version 2.0. '
+            'Use set(microsecond={}) instead.'.format(microsecond),
+            PendulumDeprecationWarning,
+            stacklevel=2
+        )
 
-    def _setter(self, **kwargs):
+        return self.set(microsecond=microsecond)
+
+    def set(self, **kwargs):
         kwargs['tzinfo'] = True
 
         return self._tz.convert(self.replace(**kwargs))
 
     def timezone_(self, tz):
+        warnings.warn(
+            'The timezone_() method will be removed in version 2.0. '
+            'Use set(tz={}) instead.'.format(tz),
+            PendulumDeprecationWarning,
+            stacklevel=2
+        )
+
         return self.__class__(
             self.year, self.month, self.day,
             self.hour, self.minute, self.second, self.microsecond,
@@ -541,9 +588,22 @@ class Pendulum(Date, datetime.datetime):
         )
 
     def tz_(self, tz):
+        warnings.warn(
+            'The tz_() method will be removed in version 2.0. '
+            'Use set(tz={}) instead.'.format(tz),
+            PendulumDeprecationWarning,
+            stacklevel=2
+        )
+
         return self.timezone_(tz)
 
     def timestamp_(self, timestamp, tz=UTC):
+        warnings.warn(
+            'The timestamp_() method will be removed in version 2.0.',
+            PendulumDeprecationWarning,
+            stacklevel=2
+        )
+
         return self.create_from_timestamp(timestamp, tz)
 
     @property
@@ -615,10 +675,30 @@ class Pendulum(Date, datetime.datetime):
 
     @property
     def local(self):
+        warnings.warn(
+            'The local property will be removed in version 2.0. '
+            'Use is_local() instead.',
+            PendulumDeprecationWarning,
+            stacklevel=2
+        )
+
+        return self.is_local()
+
+    def is_local(self):
         return self.offset == self.in_timezone(self._local_timezone()).offset
 
     @property
     def utc(self):
+        warnings.warn(
+            'The utc property will be removed in version 2.0. '
+            'Use is_utc() instead.',
+            PendulumDeprecationWarning,
+            stacklevel=2
+        )
+
+        return self.is_utc()
+
+    def is_utc(self):
         return self.offset == 0
 
     @property
@@ -708,6 +788,13 @@ class Pendulum(Date, datetime.datetime):
 
         :rtype: Pendulum
         """
+        warnings.warn(
+            'The with_date_time() method will be removed in version 2.0. '
+            'Use both on() and at() methods instead.',
+            PendulumDeprecationWarning,
+            stacklevel=2
+        )
+
         return self.replace(
             year=year, month=month, day=day,
             hour=hour, minute=minute, second=second,
@@ -723,6 +810,12 @@ class Pendulum(Date, datetime.datetime):
 
         :rtype: Pendulum
         """
+        warnings.warn(
+            'The with_time_from_string() method will be removed in version 2.0.',
+            PendulumDeprecationWarning,
+            stacklevel=2
+        )
+
         time = time.split(':')
 
         hour = int(time[0])
@@ -763,6 +856,12 @@ class Pendulum(Date, datetime.datetime):
         :type timestamp: int or float
         :rtype: Pendulum
         """
+        warnings.warn(
+            'The with_timestamp() method will be removed in version 2.0.',
+            PendulumDeprecationWarning,
+            stacklevel=2
+        )
+
         dt = datetime.datetime.fromtimestamp(timestamp, UTC).astimezone(self._tz)
 
         return self.instance(dt)
@@ -951,6 +1050,12 @@ class Pendulum(Date, datetime.datetime):
 
         :rtype: bool
         """
+        warnings.warn(
+            'The between() method will be removed in version 2.0.',
+            PendulumDeprecationWarning,
+            stacklevel=2
+        )
+
         if dt1 > dt2:
             dt1, dt2 = dt2, dt1
 
@@ -1002,6 +1107,12 @@ class Pendulum(Date, datetime.datetime):
 
         :rtype: Pendulum
         """
+        warnings.warn(
+            'The min_() method will be removed in version 2.0.',
+            PendulumDeprecationWarning,
+            stacklevel=2
+        )
+
         if dt is None:
             dt = Pendulum.now(self.timezone)
 
@@ -1019,6 +1130,12 @@ class Pendulum(Date, datetime.datetime):
 
         :rtype: Pendulum
         """
+        warnings.warn(
+            'The minimum() method will be removed in version 2.0.',
+            PendulumDeprecationWarning,
+            stacklevel=2
+        )
+
         return self.min_(dt)
 
     def max_(self, dt=None):
@@ -1030,6 +1147,12 @@ class Pendulum(Date, datetime.datetime):
 
         :rtype: Pendulum
         """
+        warnings.warn(
+            'The max_() method will be removed in version 2.0.',
+            PendulumDeprecationWarning,
+            stacklevel=2
+        )
+
         if dt is None:
             dt = Pendulum.now(self.timezone)
 
@@ -1047,6 +1170,12 @@ class Pendulum(Date, datetime.datetime):
 
         :rtype: Pendulum
         """
+        warnings.warn(
+            'The maximum() method will be removed in version 2.0.',
+            PendulumDeprecationWarning,
+            stacklevel=2
+        )
+
         return self.max_(dt)
 
     def is_yesterday(self):
@@ -1055,6 +1184,12 @@ class Pendulum(Date, datetime.datetime):
 
         :rtype: bool
         """
+        warnings.warn(
+            'The is_yesterday() method will be removed in version 2.0.',
+            PendulumDeprecationWarning,
+            stacklevel=2
+        )
+
         return self.to_date_string() == self.yesterday(self._tz).to_date_string()
 
     def is_today(self):
@@ -1063,6 +1198,12 @@ class Pendulum(Date, datetime.datetime):
 
         :rtype: bool
         """
+        warnings.warn(
+            'The is_today() method will be removed in version 2.0.',
+            PendulumDeprecationWarning,
+            stacklevel=2
+        )
+
         return self.to_date_string() == self.now(self._tz).to_date_string()
 
     def is_tomorrow(self):
@@ -1071,6 +1212,11 @@ class Pendulum(Date, datetime.datetime):
 
         :rtype: bool
         """
+        warnings.warn(
+            'The is_tomorrow() method will be removed in version 2.0.',
+            PendulumDeprecationWarning,
+            stacklevel=2
+        )
         return self.to_date_string() == self.tomorrow(self._tz).to_date_string()
 
     def is_future(self):
@@ -1107,6 +1253,11 @@ class Pendulum(Date, datetime.datetime):
 
         :rtype: bool
         """
+        warnings.warn(
+            'The is_same_day() method will be removed in version 2.0.',
+            PendulumDeprecationWarning,
+            stacklevel=2
+        )
         dt = self._get_datetime(dt, True)
 
         return self.to_date_string() == dt.to_date_string()
@@ -1225,6 +1376,12 @@ class Pendulum(Date, datetime.datetime):
 
         :rtype: Pendulum
         """
+        warnings.warn(
+            'The add_timedelta() method will be removed in version 2.0.',
+            PendulumDeprecationWarning,
+            stacklevel=2
+        )
+
         if isinstance(delta, Period):
             return self.add(
                 years=delta.years, months=delta.months,
@@ -1244,6 +1401,12 @@ class Pendulum(Date, datetime.datetime):
 
         :rtype: Pendulum
         """
+        warnings.warn(
+            'The subtract_timedelta() method will be removed in version 2.0.',
+            PendulumDeprecationWarning,
+            stacklevel=2
+        )
+
         if isinstance(delta, Period):
             return self.subtract(
                 years=delta.years, months=delta.months,
@@ -1263,6 +1426,13 @@ class Pendulum(Date, datetime.datetime):
 
         :rtype: int
         """
+        warnings.warn(
+            'The seconds_since_midnight() '
+            'method will be removed in version 2.0.',
+            PendulumDeprecationWarning,
+            stacklevel=2
+        )
+
         return self.diff(self.start_of('day')).in_seconds()
 
     def seconds_until_end_of_day(self):
@@ -1271,6 +1441,13 @@ class Pendulum(Date, datetime.datetime):
 
         :rtype: int
         """
+        warnings.warn(
+            'The seconds_until_end_of_day() '
+            'method will be removed in version 2.0.',
+            PendulumDeprecationWarning,
+            stacklevel=2
+        )
+
         return self.diff(self.end_of('day')).in_seconds()
 
     def diff(self, dt=None, abs=True):
